==> enterprisemodules-ora_config-3.18.3.tar.gz: enterprisemodules-ora_config-3.18.3/lib/puppet/type/ora_home_option/unified_auditing.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/settings'

newproperty(:unified_auditing) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Settings

  desc <<-EOD

      This resource allows you to manage(enable/disable) the Unified Auditing option in an Oracle database home starting from version 19c.

          ora_home_option { '/u01/app/oracle/product/19.0.0/db_home1':
            ...
            unified_auditing => 'enabled',
            ...
          }

  EOD

  newvalues(:disabled, :enabled)
  data_type("Optional[Enum['disabled', 'enabled']]")

  to_translate_to_resource do |raw_resource|
    raw_resource['UNIAUD']
  end

  on_modify do
    flag = enabled? ? 'uniaud_on' : 'uniaud_off'
    oracle_home = resource.name
    ora_install_homes = Facter::value('ora_install_homes') || {}
    # Todo: get rid of settings dependency and rely on the facts, so we can also manage this property for homes that don't have a settings entry
    oh_settings_entry = configuration.select { |db, settings| settings['oracle_home'] == oracle_home }.first
    os_user = ora_install_homes.dig(oracle_home, 'os_user').nil? ? configuration_value_for(oh_settings_entry.first, 'os_user') : ora_install_homes.dig(oracle_home, 'os_user')
    command = "su - #{os_user} -c \"export ORACLE_HOME=#{oracle_home}; cd #{oracle_home}/rdbms/lib; make -f ins_rdbms.mk #{flag} ioracle\""
    options = { :failonfail => true, :combine => true }
    Puppet::Util::Execution.execute(command, options)
  end

  private

  def enabled?
    value.to_s == 'enabled'
  end

end

==> enterprisemodules-ora_config-3.18.5.tar.gz: enterprisemodules-ora_config-3.18.5/lib/puppet/type/ora_home_option/unified_auditing.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/settings'

newproperty(:unified_auditing) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Settings

  desc <<-DESC

      This resource allows you to manage(enable/disable) the Unified Auditing option in an Oracle database home starting from version 19c.

          ora_home_option { '/u01/app/oracle/product/19.0.0/db_home1':
            ...
            unified_auditing => 'enabled',
            ...
          }

  DESC

  newvalues(:disabled, :enabled)
  data_type("Optional[Enum['disabled', 'enabled']]")

  to_translate_to_resource do |raw_resource|
    raw_resource['UNIAUD']
  end

  on_modify do
    flag = enabled? ? 'uniaud_on' : 'uniaud_off'
    oracle_home = resource.name
    ora_install_homes = Facter.value('ora_install_homes') || {}
    # TODO: get rid of settings dependency and rely on the facts, so we can also manage this property for homes that don't have a settings entry
    oh_settings_entry = configuration.find { |_db, settings| settings['oracle_home'] == oracle_home }
    os_user = ora_install_homes.dig(oracle_home, 'os_user').nil? ? configuration_value_for(oh_settings_entry.first, 'os_user') : ora_install_homes.dig(oracle_home, 'os_user')
    command = "su - #{os_user} -c \"export ORACLE_HOME=#{oracle_home}; cd #{oracle_home}/rdbms/lib; make -f ins_rdbms.mk #{flag} ioracle\""
    options = { :failonfail => true, :combine => true }
    Puppet::Util::Execution.execute(command, options)
  end

  private

  def enabled?
    value.to_s == 'enabled'
  end
end
